Skip to content

Enshrouded

Enshrouded is a game of survival, crafting, and Action RPG combat, set within a sprawling voxel-based continent. As you journey across the mountains and deserts of an open world, you are free to choose your path and shape your destiny.

egg-enshrouded.json

updated

Ports

Add an allocation on the node for each port.

  • Game/Query 15637

Install

Installer image
ghcr.io/ptero-eggs/installers:debian
Steam app
2278520
Steam login
not required
Install script
70 lines

Image

  • SteamCMD, Proton ghcr.io/ptero-eggs/steamcmd:proton

Panel features

  • steam_disk_space

    The Panel tells the user when SteamCMD does not have enough disk space.

Startup

The Panel runs this command to start the server. It replaces each variable in the command with the value of that variable.

10 variables

Startup command

rm ./logs/enshrouded_server.log; proton run ./enshrouded_server.exe & ENS_PID=$! ; tail -c0 -F ./logs/enshrouded_server.log --pid=$ENS_PID
  • Name of the server

    SRV_NAMEUsers can edit

    required|string

  • Maximum number of players allowed

    MAX_PLAYERSUsers can edit

    required|numeric

  • Password for the Admin user-group. Players using this password get: - canAccessInventories: true - canEditBase: true - canExtendBase: true - canKickBan: true. The passwords for the usergroups can not all be the same/empty/only numerical

    SRV_PWUsers can edit

    required|string|not_regex:/^\d+$/

  • Password for the Friend user-group. Players using this password get: - canAccessInventories: true - canEditBase: true - canExtendBase: true - canKickBan: false. The passwords for the usergroups can not all be the same/empty/only numerical

    SRV_PW2Users can edit

    required|string|not_regex:/^\d+$/

  • Password for the Guest user-group. Players using this password get: - canAccessInventories: false - canEditBase: false - canExtendBase: false - canKickBan: false. The passwords for the usergroups can not all be the same/empty/only numerical

    SRV_PW3Users can edit

    required|string|not_regex:/^\d+$/

  • Password for the Visitor user-group. Players using this password get: - canAccessInventories: false - canEditBase: false - canExtendBase: false - canKickBan: false - canEditWorld: false The passwords for the usergroups can not all be the same/empty/only numerical

    SRV_PW4Users can edit

    required|string|not_regex:/^\d+$/

  • Steam App ID

    SRCDS_APPIDUsers cannot see

    required|string|in:2278520

  • Whether to install the Windows version

    WINDOWS_INSTALLUsers cannot see

    required|boolean

  • Enable automatic updates on boot

    AUTO_UPDATEUsers can edit

    required|boolean

  • Validate the server files through Steam

    VALIDATEUsers can edit

    required|boolean

Wings

Stop command
^C (SIGINT)
Running when the console shows
[Session] 'HostOnline' (up)!

Files Wings edits

Wings sets these values in these files before each start.

enshrouded_server.json json

name
{{server.build.env.SRV_NAME}}
queryPort
{{server.build.default.port}}
slotCount
{{server.build.env.MAX_PLAYERS}}
userGroups[0].password
{{server.build.env.SRV_PW}}
userGroups[1].name
Friend
userGroups[1].password
{{server.build.env.SRV_PW2}}
userGroups[2].name
Guest
userGroups[2].password
{{server.build.env.SRV_PW3}}
userGroups[3].name
Visitor
userGroups[3].password
{{server.build.env.SRV_PW4}}

Readme

Enshrouded

Game Description

Enshrouded is a game of survival, crafting, and Action RPG combat, set within a sprawling voxel-based continent. As you journey across the mountains and deserts of an open world, you are free to choose your path and shape your destiny.

Ignite the Ancient power of the Flame, and piece together the fragments of a story that unfolds below the surface.

Usefull links

Author & Contributers

Name Github Profile Buy me a Coffee
Red-Banana-Official https://github.com/Red-Banana-Official /
Vapok https://github.com/Vapok https://www.buymeacoffee.com/vapok
QuintenQVD0 https://github.com/QuintenQVD0 /
gOOvER https://github.com/gOOvER https://ko-fi.com/B0B351D0Q

Server Ports

By default Enshrouded requires 1 port.

Port default
Game/Query 15637

Configuration

Where is the Server Configuration Stored?

The Enshrouded dedicated server configuration is stored in enshrouded_server.json, which is automatically managed by this egg.

Instead of manually editing this file, you can set most key values directly in the Pterodactyl Panel using environment variables.


How to Configure the Server

Most settings can be modified via Pterodactyl's environment variables.
Go to your Pterodactyl Panel → Server Settings, where you can edit:

  • Server Name (SRV_NAME) – The name players will see in the server list.
  • User Group Passwords:
    • Admin Group (SRV_PW) – Grants admin privileges.
    • Friend Group (SRV_PW2) – Grants reduced admin privileges.
    • Guest Group (SRV_PW3) – General access for users.
    • Visitor Group (SRV_PW4) – Minimal access for visitors.
  • Max Players (MAX_PLAYERS) – Number of player slots (1-16).

Other settings, such as game settings, IP binding, and log locations, are still managed in enshrouded_server.json


Default Configuration File (enshrouded_server.json)

On first startup, the server will generate the following structure:

{
    "enableTextChat": false,
    "enableVoiceChat": false,
    "gameSettings": {
        "aggroPoolAmount": "Normal",
        "bossDamageFactor": 1,
        "bossHealthFactor": 1,
        "dayTimeDuration": 1800000000000,
        "enableDurability": true,
        "enableGliderTurbulences": true,
        "enableStarvingDebuff": false,
        "enemyDamageFactor": 1,
        "enemyHealthFactor": 1,
        "enemyPerceptionRangeFactor": 1,
        "enemyStaminaFactor": 1,
        "experienceCombatFactor": 1,
        "experienceExplorationQuestsFactor": 1,
        "experienceMiningFactor": 1,
        "factoryProductionSpeedFactor": 1,
        "foodBuffDurationFactor": 1,
        "fromHungerToStarving": 600000000000,
        "miningDamageFactor": 1,
        "nightTimeDuration": 720000000000,
        "pacifyAllEnemies": false,
        "perkCostFactor": 1,
        "perkUpgradeRecyclingFactor": 0.5,
        "plantGrowthSpeedFactor": 1,
        "playerBodyHeatFactor": 1,
        "playerHealthFactor": 1,
        "playerManaFactor": 1,
        "playerStaminaFactor": 1,
        "randomSpawnerAmount": "Normal",
        "resourceDropStackAmountFactor": 1,
        "shroudTimeFactor": 1,
        "tamingStartleRepercussion": "LoseSomeProgress",
        "threatBonus": 1,
        "tombstoneMode": "AddBackpackMaterials",
        "weatherFrequency": "Normal",
        "playerDivingTimeFactor": 1,
        "fishingDifficulty": "Normal",
        "curseModifier": "Normal"
    },
    "gameSettingsPreset": "Default",
    "ip": "0.0.0.0",
    "logDirectory": "./logs",
    "name": "My Enshrouded Server",
    "queryPort": 15637,
    "saveDirectory": "./savegame",
    "slotCount": 16,
    "tags": [],
    "userGroups": [
        {
            "canAccessInventories": true,
            "canEditBase": true,
            "canExtendBase": true,
            "canKickBan": true,
            "canEditWorld": true,
            "name": "Admin",
            "password": "ChangeMe1",
            "reservedSlots": 0
        },
        {
            "canAccessInventories": true,
            "canEditBase": true,
            "canExtendBase": true,
            "canKickBan": false,
            "canEditWorld": true,
            "name": "Friend",
            "password": "ChangeMe2",
            "reservedSlots": 1
        },
        {
            "canAccessInventories": false,
            "canEditBase": false,
            "canExtendBase": false,
            "canKickBan": false,
            "canEditWorld": false,
            "name": "Guest",
            "password": "ChangeMe3",
            "reservedSlots": 3
        },
        {
            "canAccessInventories": false,
            "canEditBase": false,
            "canExtendBase": false,
            "canKickBan": false,
            "canEditWorld": false,
            "name": "Visitor",
            "password": "ChangeMe4",
            "reservedSlots": 0
        }
    ],
    "bannedAccounts": [],
    "voiceChatMode": "Proximity"
}

Installation/System Requirements

Recommended Extra info
Processor Recent x86/64 (AMD/Intel) processor. You need min 4 Cores for the Server.
RAM 4-6 GB
Storage 30 GB (or more, depending on save size or frequency)

Server not showing in Serverlist?

The fact that the server is not displayed in the server list is a known problem.

As a workaround, you can add the server as a favourite via IP:queryport in the Steam server browser. The server should then be at the top of the ingame server list

Changes

  1. Enshrouded: Add visitor group and new settings, update var descriptions and validation

    · Red Banana · 5900f40

  2. added extra info to descriptions

    · Red Banana · 8099e46

  3. additional changes

    · Red Banana · fcb0ec0

  4. Some additional changes to the Enshrouded Egg

    · Red Banana · a616260

  5. Enshrouded: Fix for new password/user group support

    · Red Banana · 31683a0

  6. Add steamcmd based eggs

    · Daniel Barton · 60ef9fb

All changes on GitHub

Problem with this egg?

Open an issue on GitHub. Include your Panel and Wings versions.

Install script 70 lines bash in ghcr.io/ptero-eggs/installers:debian Show
#!/bin/bash
# steamcmd Base Installation Script
#
# Server Files: /mnt/server
# Image to install with is 'ghcr.io/ptero-eggs/installers:debian'
#
# Variables
# STEAM_USER, STEAM_PASS, STEAM_AUTH - Steam user setup. If a user has 2fa enabled it will most likely fail due to timeout. Leave blank for anon install.
# WINDOWS_INSTALL - if it's a windows server you want to install set to 1
# SRCDS_APPID - steam app id found here - https://developer.valvesoftware.com/wiki/Dedicated_Servers_List
# SRCDS_BETAID - beta branch of a steam app. Leave blank to install normal branch
# SRCDS_BETAPASS - password for a beta branch should one be required during private or closed testing phases.. Leave blank for no password.
# INSTALL_FLAGS - Any additional SteamCMD  flags to pass during install.. Keep in mind that steamcmd auto update process in the docker image might overwrite or ignore these when it performs update on server boot.
# AUTO_UPDATE - Adding this variable to the egg allows disabling or enabling automated updates on boot. Boolean value. 0 to disable and 1 to enable.
#

# Install packages. Default packages below are not required if using our existing install image thus speeding up the install process.
#apt -y update
#apt -y --no-install-recommends install curl lib32gcc-s1 ca-certificates

## just in case someone removed the defaults.
if [[ "${STEAM_USER}" == "" ]] || [[ "${STEAM_PASS}" == "" ]]; then
    echo -e "steam user is not set.\n"
    echo -e "Using anonymous user.\n"
    STEAM_USER=anonymous
    STEAM_PASS=""
    STEAM_AUTH=""
else
    echo -e "user set to ${STEAM_USER}"
fi

## Download and install SteamCMD
cd /tmp
mkdir -p /mnt/server/steamcmd
curl -sSL -o steamcmd.tar.gz https://steamcdn-a.akamaihd.net/client/installer/steamcmd_linux.tar.gz
tar -xzvf steamcmd.tar.gz -C /mnt/server/steamcmd
mkdir -p /mnt/server/steamapps # Fix steamcmd disk write error when this folder is missing
cd /mnt/server/steamcmd

# SteamCMD fails otherwise for some reason, even running as root.
# This is changed at the end of the install process anyways.
chown -R root:root /mnt
export HOME=/mnt/server

## install game using steamcmd
./steamcmd.sh +force_install_dir /mnt/server +login ${STEAM_USER} ${STEAM_PASS} ${STEAM_AUTH} $( [[ "${WINDOWS_INSTALL}" == "1" ]] && printf %s '+@sSteamCmdForcePlatformType windows' ) +app_update ${SRCDS_APPID} $( [[ -z ${SRCDS_BETAID} ]] || printf %s "-beta ${SRCDS_BETAID}" ) $( [[ -z ${SRCDS_BETAPASS} ]] || printf %s "-betapassword ${SRCDS_BETAPASS}" ) ${INSTALL_FLAGS} validate +quit ## other flags may be needed depending on install. looking at you cs 1.6

## set up 32 bit libraries
mkdir -p /mnt/server/.steam/sdk32
cp -v linux32/steamclient.so ../.steam/sdk32/steamclient.so

## set up 64 bit libraries
mkdir -p /mnt/server/.steam/sdk64
cp -v linux64/steamclient.so ../.steam/sdk64/steamclient.so

## Downloading the servers default config file
FILE=$HOME/enshrouded_server.json
if [ -f "$FILE" ]; then
  echo -e "ennshrouded_server.json configuration found"
else  
  echo -e "No enshrouded_server.json found. Downloading default configuration.."
  cd $HOME
  curl -sSL -o enshrouded_server.json https://raw.githubusercontent.com/Ptero-Eggs/game-eggs/refs/heads/main/enshrouded/enshrouded_server.json
  echo -e "Configuration file downloaded"
fi

## End of installation
echo -e "${BLUE}-------------------------------------------------${NC}"
echo -e "${GREEN}Installation completed...${NC}"
echo -e "${BLUE}-------------------------------------------------${NC}"